@@ -146,6 +146,7 @@ class SparkJobParameters(abc.ABC):
 class RetrievalJobParameters(SparkJobParameters):
     def __init__(
         self,
+        project: str,
         feature_tables: List[Dict],
         feature_tables_sources: List[Dict],
         entity_source: Dict,
@@ -155,6 +156,7 @@ class RetrievalJobParameters(SparkJobParameters):
     ):
         """
         Args:
+            project (str): Client project
             entity_source (Dict): Entity data source configuration.
             feature_tables_sources (List[Dict]): List of feature tables data sources configurations.
             feature_tables (List[Dict]): List of feature table specification.
@@ -261,6 +263,7 @@ class RetrievalJobParameters(SparkJobParameters):
                 }
 
         """
+        self._project = project
         self._feature_tables = feature_tables
         self._feature_tables_sources = feature_tables_sources
         self._entity_source = entity_source
@@ -268,6 +271,9 @@ class RetrievalJobParameters(SparkJobParameters):
         self._extra_packages = extra_packages if extra_packages else []
         self._checkpoint_path = checkpoint_path
 
+    def get_project(self) -> str:
+        return self._project
+
     def get_name(self) -> str:
         all_feature_tables_names = [ft["name"] for ft in self._feature_tables]
         return f"{self.get_job_type().to_pascal_case()}-{'-'.join(all_feature_tables_names)}"
@@ -569,13 +575,13 @@ class StreamIngestionJobParameters(IngestionJobParameters):
         feature_table: Dict,
         source: Dict,
         jar: str,
-        extra_jars: List[str],
-        redis_host: Optional[str],
-        redis_port: Optional[int],
-        redis_password: Optional[str],
-        redis_ssl: Optional[bool],
-        bigtable_project: Optional[str],
-        bigtable_instance: Optional[str],
+        extra_jars: List[str] = None,
+        redis_host: Optional[str] = None,
+        redis_port: Optional[int] = None,
+        redis_password: Optional[str] = None,
+        redis_ssl: Optional[bool] = None,
+        bigtable_project: Optional[str] = None,
+        bigtable_instance: Optional[str] = None,
         cassandra_host: Optional[str] = None,
         cassandra_port: Optional[int] = None,
         statsd_host: Optional[str] = None,
@@ -615,7 +621,7 @@ class StreamIngestionJobParameters(IngestionJobParameters):
         return SparkJobType.STREAM_INGESTION
 
     def get_extra_jar_paths(self) -> List[str]:
-        return self._extra_jars
+        return self._extra_jars if self._extra_jars else []
 
     def get_arguments(self) -> List[str]:
         args = super().get_arguments()
@@ -627,8 +633,15 @@ class StreamIngestionJobParameters(IngestionJobParameters):
         return args
 
     def get_job_hash(self) -> str:
+        sorted_feature_table = self._feature_table.copy()
+        sorted_feature_table["entities"] = sorted(
+            self._feature_table["entities"], key=lambda x: x["name"]
+        )
+        sorted_feature_table["features"] = sorted(
+            self._feature_table["features"], key=lambda x: x["name"]
+        )
         job_json = json.dumps(
-            {"source": self._source, "feature_table": self._feature_table},
+            {"source": self._source, "feature_table": sorted_feature_table},
             sort_keys=True,
         )
         return hashlib.md5(job_json.encode()).hexdigest()
